@@ -2,9 +2,9 @@ package Dist::Zilla::Plugin::Pcore::PAR;
 
 use Moose;
 use Pcore;
-use Config();
-use Archive::Zip();
-use Module::Metadata();
+use Config qw[];
+use Archive::Zip qw[];
+use Module::Metadata qw[];
 use PAR::Filter;
 use Pcore::Src::File;
 use Term::ANSIColor qw[:constants];
@@ -315,6 +315,7 @@ sub _add_perl_source {
                 $src = Pcore::Src::File->new(
                     {   action      => 'compress',
                         path        => $to,
+                        is_realpath => 0,
                         in_buffer   => $src,
                         filter_args => {             #
                             perl_compress => 1,
@@ -326,6 +327,7 @@ sub _add_perl_source {
                 $src = Pcore::Src::File->new(
                     {   action      => 'compress',
                         path        => $to,
+                        is_realpath => 0,
                         in_buffer   => $src,
                         filter_args => {
                             perl_strip_maintain_linum => 1,
@@ -358,6 +360,7 @@ sub _add_perl_source {
         $src = Pcore::Src::File->new(
             {   action      => 'compress',
                 path        => $to,
+                is_realpath => 0,
                 in_buffer   => $src,
                 filter_args => {
                     perl_strip_maintain_linum => 1,
@@ -372,6 +375,7 @@ sub _add_perl_source {
             $src = Pcore::Src::File->new(
                 {   action      => 'compress',
                     path        => $to,
+                    is_realpath => 0,
                     in_buffer   => $src,
                     filter_args => {
                         perl_strip_maintain_linum => 0,
@@ -385,6 +389,7 @@ sub _add_perl_source {
             $src = Pcore::Src::File->new(
                 {   action      => 'compress',
                     path        => $to,
+                    is_realpath => 0,
                     in_buffer   => $src,
                     filter_args => {             #
                         perl_compress => 1,
@@ -494,6 +499,7 @@ sub _repack_par {
             $content = Pcore::Src::File->new(
                 {   action      => 'compress',
                     path        => $filename,
+                    is_realpath => 0,
                     in_buffer   => \$content,
                     filter_args => {             #
                         perl_compress => 1,
@@ -597,15 +603,15 @@ __PACKAGE__->meta->make_immutable;
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
 ## │    3 │ 138                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 152, 240, 262, 577   │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
+## │    3 │ 152, 240, 262, 583   │ ValuesAndExpressions::ProhibitMismatchedOperators - Mismatched operator                                        │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 467                  │ RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional                     │
+## │    3 │ 472                  │ RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional                     │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 494                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
+## │    2 │ 499                  │ ValuesAndExpressions::ProhibitLongChainsOfMethodCalls - Found method-call chain of length 4                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    2 │ 524, 526             │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
+## │    2 │ 530, 532             │ ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 483, 489, 530        │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
+## │    1 │ 488, 494, 536        │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
