@@ -1,6 +1,6 @@
-package Pcore v0.11.0;
+package Pcore v0.11.1;
 
-use v5.20.0;
+use v5.20.2;
 use utf8;
 use strict;
 use warnings ( qw[all], FATAL => qw[utf8], NONFATAL => qw[] );
@@ -15,28 +15,29 @@ no multidimensional;
 # https://rt.cpan.org/Ticket/Display.html?id=102321
 # no if $^O !~ /MSWin/sm, indirect => qw[fatal];
 
-use namespace::clean();
+use namespace::clean qw[];
 
-use Encode();    ## no critic qw(Modules::ProhibitEvilModules)
+use Encode qw[];
 
 # preload Moo
 use Import::Into;
-use Moo();          ## no critic qw(Modules::ProhibitEvilModules)
-use Moo::Role();    ## no critic qw(Modules::ProhibitEvilModules)
+use Moo qw[];
+use Moo::Role qw[];
 
-# console related packages
-use Term::ANSIColor();
-use PerlIO::encoding();
+# preload console related packages
+use Term::ANSIColor qw[];
+use PerlIO::encoding qw[];
 
-use B::Hooks::AtRuntime();
-use B::Hooks::EndOfScope::XS();
+use B::Hooks::AtRuntime qw[];
+use B::Hooks::EndOfScope::XS qw[];
 
-# AnyEvent
+# preload AnyEvent
 use EV;
 use AnyEvent;
 
 # define global variables
 BEGIN {
+    $Pcore::INITIALISED      = 0;                         # core initialisation flag
     $Pcore::CALLER           = caller;                    # namespace, from P was required first time
     $Pcore::EMBEDDED         = 0;                         # Pcore::Core used in embedded mode
     $Pcore::IS_PAR           = $ENV{PAR_TEMP} ? 1 : 0;    # process runned from PAR
@@ -51,7 +52,7 @@ BEGIN {
         require Filter::Crypto::Decrypt if $Pcore::IS_PAR;
     };
 
-    # define %EXPORT_PRAGMAS
+    # define %EXPORT_PRAGMAS for exporter
     %Pcore::EXPORT_PRAGMAS = (
         config      => 0,    # mark package as perl config, used automatically during .perl config evaluation, do not use directly!!!
         embedded    => 0,    # run in embedded mode
@@ -65,6 +66,7 @@ BEGIN {
         types       => 0,    # export types
     );
 
+    # configure standard library
     $Pcore::UTIL = {
         bit      => 'Pcore::Util::Bit',
         capture  => 'Pcore::Util::Capture',
@@ -94,17 +96,24 @@ BEGIN {
     };
 }
 
-use Pcore::Core::Exporter();
+use Pcore::Core::Exporter qw[];
 
 sub import {
     my $self = shift;
 
-    # parse tags and pragmas
-    my ( $tags, $pragma ) = Pcore::Core::Exporter::Helper->parse_import( $self, @_ );
-
     # find caller
     my $caller = caller;
 
+    # parse tags and pragmas
+    my ( $tags, $pragma, $data ) = Pcore::Core::Exporter::Helper->parse_import( $self, @_ );
+
+    # initialize Pcore if called first time from non-core package
+    if ( !$Pcore::INITIALISED && $caller eq $Pcore::CALLER ) {
+        $Pcore::INITIALISED = 1;
+
+        _CORE_INIT($data);
+    }
+
     # export perl pragmas
     utf8->import();
     strict->import();
@@ -268,7 +277,7 @@ sub _import_moo {
 
         my $has = *{ $args{caller} . '::has' }{CODE};
 
-        no warnings qw[redefine];    ## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+        no warnings qw[redefine];
 
         *{ $args{caller} . '::has' } = sub {
             my ( $name_proto, %spec ) = @_;
@@ -315,13 +324,13 @@ sub _import_types {
         local $ENV{PERL_TYPES_STANDARD_STRICTNUM} = 0;    # 0 - Num = LaxNum, 1 - Num = StrictNum
 
         require Pcore::Core::Types;
-        require Types::TypeTiny;                          ## no critic qw(Modules::ProhibitEvilModules)
-        require Types::Standard;                          ## no critic qw(Modules::ProhibitEvilModules)
-        require Types::Common::Numeric;                   ## no critic qw(Modules::ProhibitEvilModules)
+        require Types::TypeTiny;
+        require Types::Standard;
+        require Types::Common::Numeric;
 
-        # require Types::Common::String;     ## no critic qw(Modules::ProhibitEvilModules)
-        # require Types::Encodings();        ## no critic qw(Modules::ProhibitEvilModules)
-        # require Types::XSD::Lite();        ## no critic qw(Modules::ProhibitEvilModules)
+        # require Types::Common::String;
+        # require Types::Encodings();
+        # require Types::XSD::Lite();
     }
 
     Types::TypeTiny->import( { into => $args{caller} }, qw[StringLike HashLike ArrayLike CodeLike TypeTiny] );
@@ -376,18 +385,15 @@ sub _apply_roles {
 # CORE compilation phase
 use Pcore::Core::Constants qw[:CORE];
 use Pcore::Core::EV qw[:CORE];
-use Pcore::Core::Bootstrap qw[:CORE];
+use Pcore::Core::Bootstrap qw[];
 use Pcore::Core::Dump qw[:CORE];
-use Pcore::Core::Exception qw[:CORE];
-use Pcore::Core::H qw[:CORE];
+use Pcore::Core::Exception qw[];
+use Pcore::Core::H qw[];
 use Pcore::Core::Log qw[:CORE];
 use Pcore::Core::I18N qw[:CORE];
+use Pcore::Core::CLI qw[];
 
-use Pcore::Core::CLI();
-
-_CORE_INIT();
-
-sub _CORE_INIT {
+sub _CORE_INIT ($proc_cfg) {
 
     # set default fallback mode for all further :encoding I/O layers
     $PerlIO::encoding::fallback = Encode::FB_CROAK | Encode::STOP_AT_PARTIAL;
@@ -415,11 +421,11 @@ sub _CORE_INIT {
         $_ = Encode::decode( $Pcore::ENCODING_CONSOLE, $_, Encode::FB_CROAK );
     }
 
-    Pcore::Core::Bootstrap::CORE_INIT();    # load default configs
+    # configure run-time environment
+    Pcore::Core::Bootstrap::CORE_INIT($proc_cfg);
 
     _configure_console();
 
-    Pcore::Core::EV::CORE_INIT();           # create global event queue
     Pcore::Core::Log::CORE_INIT();          # set default log pipes
     Pcore::Core::Exception::CORE_INIT();    # set $SIG{__DIE__}, $SIG{__WARN__}, $SIG->{INT}, $SIG->{TERM} handlers
     Pcore::Core::I18N::CORE_INIT();         # configure default I18N locations
@@ -547,17 +553,23 @@ sub _configure_console {
 1;
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
-## PerlCritic profile "pcore-script" policy violations:
+## PerlCritic profile "common" policy violations:
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 48                   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
+## │    3 │ 49                   │ ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 99                   │ Subroutines::ProhibitExcessComplexity - Subroutine "import" with high complexity score (26)                    │
+## │    3 │ 101                  │ Subroutines::ProhibitExcessComplexity - Subroutine "import" with high complexity score (28)                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 157                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
+## │    3 │ 166                  │ Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 495                  │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
+## │    3 │ 410, 458, 475, 523,  │ ErrorHandling::RequireCarping - "die" used instead of "croak"                                                  │
+## │      │ 524, 525, 531, 532,  │                                                                                                                │
+## │      │ 533, 538, 539, 540   │                                                                                                                │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    1 │ 413                  │ InputOutput::RequireCheckedSyscalls - Return value of flagged function ignored - say                           │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
+## │    1 │ 501                  │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
