@@ -30,4 +30,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::Autoload::Role
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
