@@ -1,15 +1,15 @@
 package Pcore::Core::Exception;
 
+use Pcore qw[-export];
+
 BEGIN {
-    our %EXPORT_TAGS = (
-        DEFAULT => [qw[croak cluck propagate try catch]],
-        CORE    => [qw[]],
-    );
+    our @EXPORT_OK   = qw[croak cluck propagate try catch];
+    our %EXPORT_TAGS = ();
+    our @EXPORT      = @EXPORT_OK;
 }
 
-use Pcore qw[-export];
 use Pcore::Core::Exception::Object;
-use Carp();
+use Carp qw[];
 
 our $IGNORE_ERRORS = 1;    # do not write errors to error log channel by default
 
@@ -33,7 +33,7 @@ sub CORE_INIT {
     $Error::TypeTiny::StackTrace = 0;
 
     {
-        no warnings qw[redefine];    ## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+        no warnings qw[redefine];
 
         *Carp::longmess = *Carp::shortmess = sub {
             if ( defined $_[0] ) {
