@@ -1,7 +1,7 @@
 package Pcore::Core::Exception::Object;
 
 use Pcore qw[-class !propagate];
-use Devel::StackTrace();
+use Devel::StackTrace qw[];
 use Scalar::Util qw[blessed];    ## no critic qw(Modules::ProhibitEvilModules)
 
 # string overloading can happens only from perl internals calls, such as eval in "use" or "require", or not handled "die", so we don't need full trace here
@@ -18,7 +18,8 @@ use overload                     #
   },
   bool => sub {
     return 1;
-  };
+  },
+  fallback => undef;
 
 has msg       => ( is => 'ro', isa => Str, default => q[] );
 has exit_code => ( is => 'rw', isa => Int, builder => 1 );
@@ -181,7 +182,7 @@ sub to_string {
     my %args = (
         trace       => undef,
         short_trace => 0,
-        @_
+        @_,
     );
 
     my $as_string = $self->_to_string;
@@ -213,7 +214,7 @@ sub send_log {
 
     $self->_logged(1);
 
-    $args{tags} = {                                                                            #
+    $args{tags} = {
         package    => $self->caller_package,
         filename   => $self->_caller_frame->filename,
         line       => $self->_caller_frame->line,
@@ -248,11 +249,9 @@ sub stop_propagate {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 72                   │ Variables::RequireInitializationForLocalVars - "local" variable not initialized                                │
+## │    3 │ 73                   │ Variables::RequireInitializationForLocalVars - "local" variable not initialized                                │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 221                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 181                  │ CodeLayout::RequireTrailingCommas - List declaration without trailing comma                                    │
+## │    3 │ 222                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -261,4 +260,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Core::Exception::Object
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
