@@ -79,7 +79,7 @@ sub encode {
             $res = \'undef';
         }
         else {
-            no warnings qw[redefine];    ## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+            no warnings qw[redefine];
 
             local *Data::Dumper::qquote = sub {
                 return q["] . P->text->encode_utf8( P->text->escape_scalar( $_[0] ) )->$* . q["];
@@ -94,6 +94,7 @@ sub encode {
             $res = Pcore::Src::File->new(
                 {   action      => 'decompress',
                     path        => 'config.perl',    # mark file as perl config
+                    is_realpath => 0,
                     in_buffer   => $res,
                     filter_args => {
                         perl_tidy   => '--comma-arrow-breakpoints=0',
@@ -768,7 +769,8 @@ use Pcore qw[-class];
 use overload    #
   q[""] => sub {
     return i18n( $_[0]->args->@* );
-  };
+  },
+  fallback => undef;
 
 has args => ( is => 'ro', isa => ArrayRef, required => 1 );
 
@@ -781,10 +783,10 @@ has args => ( is => 'ro', isa => ArrayRef, required => 1 );
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │                      │ Subroutines::ProhibitExcessComplexity                                                                          │
 ## │      │ 30                   │ * Subroutine "encode" with high complexity score (35)                                                          │
-## │      │ 236                  │ * Subroutine "decode" with high complexity score (31)                                                          │
+## │      │ 237                  │ * Subroutine "decode" with high complexity score (31)                                                          │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 146, 369, 397, 399,  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
-## │      │ 401, 403             │                                                                                                                │
+## │    3 │ 147, 370, 398, 400,  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │      │ 402, 404             │                                                                                                                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
