@@ -1,7 +1,7 @@
 package Pcore::Util::GeoIP;
 
 use Pcore qw[-autoload];
-use Const::Fast();
+use Const::Fast qw[];
 
 Const::Fast::const our $GEOIP_STANDARD     => 0;    # PP
 Const::Fast::const our $GEOIP_MEMORY_CACHE => 1;    # PP
