@@ -1,7 +1,7 @@
 package Pcore::Util::List;
 
 use Pcore qw[-autoload];
-use List::AllUtils();    ## no critic qw(Modules::ProhibitEvilModules)
+use List::AllUtils qw[];    ## no critic qw(Modules::ProhibitEvilModules)
 
 sub autoload {
     my $self   = shift;
@@ -22,4 +22,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Util::List
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
