@@ -2,7 +2,7 @@ package Pcore::Util::Mail;
 
 use Pcore;
 use Net::SMTPS;
-use Mail::IMAPClient();
+use Mail::IMAPClient qw[];
 
 sub send_mail {
     my $self = shift;
