@@ -1,8 +1,8 @@
 package Pcore::Util::Random;
 
 use Pcore;
-use Math::Random::ISAAC::XS();
-use Bytes::Random::Secure();    ## no critic qw(Modules::ProhibitEvilModules)
+use Math::Random::ISAAC::XS qw[];
+use Bytes::Random::Secure qw[];    ## no critic qw(Modules::ProhibitEvilModules)
 
 our $SEED_BITS        = 256;
 our $SEED_NONBLOCKING = 1;                                                                       # blocking entropy generator is more secure
@@ -53,4 +53,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Util::Random
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
