@@ -1,7 +1,7 @@
 package Pcore::Util::Scalar;
 
 use Pcore qw[-autoload];
-use Scalar::Util();    ## no critic qw(Modules::ProhibitEvilModules)
+use Scalar::Util qw[];    ## no critic qw(Modules::ProhibitEvilModules)
 
 sub is_hash {
     my $self = shift;
@@ -44,4 +44,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Util::Scalar
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
