@@ -1,8 +1,8 @@
 package Pcore::Util::Text;
 
 use Pcore qw[-autoload];
-use Encode();    ## no critic qw(Modules::ProhibitEvilModules)
-use Term::ANSIColor();
+use Encode qw[];    ## no critic qw(Modules::ProhibitEvilModules)
+use Term::ANSIColor qw[];
 
 our %ESC_ANSI_CTRL = (
     qq[\a] => q[\a],
@@ -516,4 +516,12 @@ __END__
 
 =encoding utf8
 
+=head1 NAME
+
+Pcore::Util::Text
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
 =cut
