@@ -9,7 +9,8 @@ use overload    #
   },
   q[cmp] => sub {
     return $_[0]->to_string cmp $_[1];
-  };
+  },
+  fallback => undef;
 
 has to_string => ( is => 'lazy', isa => Str, clearer => '_clear_to_string', init_arg => undef );
 
@@ -485,12 +486,12 @@ sub to_http_req ( $self, $with_auth = undef ) {
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
 ## │    3 │                      │ Subroutines::ProhibitExcessComplexity                                                                          │
-## │      │ 40                   │ * Subroutine "NEW" with high complexity score (22)                                                             │
-## │      │ 123                  │ * Subroutine "_parse" with high complexity score (26)                                                          │
+## │      │ 41                   │ * Subroutine "NEW" with high complexity score (22)                                                             │
+## │      │ 124                  │ * Subroutine "_parse" with high complexity score (26)                                                          │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 80                   │ ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         │
+## │    3 │ 81                   │ ControlStructures::ProhibitDeepNests - Code structure is deeply nested                                         │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    1 │ 180, 296             │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
+## │    1 │ 181, 297             │ CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
