@@ -3,13 +3,13 @@
 package main v0.1.0;
 
 use Pcore;
-use Const::Fast();
-use Benchmark();
-use Storable();
-use Data::Dumper();    ## no critic qw(Modules::ProhibitEvilModules)
-use JSON::XS();        ## no critic qw(Modules::ProhibitEvilModules)
-use Data::MessagePack();
-use CBOR::XS();
+use Const::Fast qw[];
+use Benchmark qw[];
+use Storable qw[];
+use Data::Dumper qw[];    ## no critic qw(Modules::ProhibitEvilModules)
+use JSON::XS qw[];        ## no critic qw(Modules::ProhibitEvilModules)
+use Data::MessagePack qw[];
+use CBOR::XS qw[];
 
 Const::Fast::const our $COUNT => -5;
 
