@@ -3,8 +3,8 @@
 package main v0.1.0;
 
 use Pcore;
-use Const::Fast();
-use Benchmark();
+use Const::Fast qw[];
+use Benchmark qw[];
 
 Const::Fast::const our $COUNT => 100_000;
 
@@ -19,7 +19,7 @@ my $res;
 $res->{'Geo::IP'} = Benchmark::timeit( $COUNT, sub { my $a = P->geoip->country_code_by_addr('192.37.51.100') } );
 
 {
-    no warnings qw[once];    ## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
+    no warnings qw[once];
 
     local $Pcore::Util::GeoIP::GEOIP_PURE_PERL = 1;
 
