@@ -3,10 +3,10 @@
 package main v0.1.0;
 
 use Pcore;
-use Const::Fast();
-use Benchmark();
-use URI();
-use Mojo::URL();
+use Const::Fast qw[];
+use Benchmark qw[];
+use URI qw[];
+use Mojo::URL qw[];
 
 Const::Fast::const our $COUNT => -3;
 
@@ -18,7 +18,9 @@ my $base_obj = P->uri($base);
 
 # initialize
 say URI->new_abs( $uri, $base );
+
 say Mojo::URL->new($uri)->to_abs( Mojo::URL->new($base) );
+
 say P->uri( $uri, $base );
 
 my $tests = {
